Leibniz Graduate School

# Leibniz Graduate School for Knowledge Media Research

Arbeitsgruppe Design und Implementation, Netzbasierter Wissensaustausch

#### Laufzeit

Start Juni 2008, Projektende offen

#### Förderung

Leibniz Gemeinschaft

#### Webseite

Graduate School

### Projektbeschreibung

Die Graduate School ist ein Programm der DoktorandInnenausbildung, das sich unter Leitung der Arbeitsgruppe "Design und Implementation integrativer Lernumgebungen" (PD Dr. Cress) und der Arbeitsgruppe "Netzbasierter Wissensaustausch" (Prof. Dr. Dr. Hesse) mit dem aktuellen Forschungsthema Social Software beschäftigt.

Die Graduate School ermöglicht es AbsolventInnen der Psychologie und anderer Disziplinen, wie z.B. der Informationswissenschaften, unter optimalen Rahmenbedingungen eine Promotion im Themenbereich Kooperative Wissenskonstruktion mit Social Software in den genannten Arbeitsgruppen durchzuführen. Die DoktorandInnen werden für jeweils drei Jahre mit Stipendien gefördert. Die Graduate School beginnt im zweiten Halbjahr 2008.

Social Software bezeichnet Technologien und Tools in virtuellen Plattformen, wie beispielsweise dem Internet, die den Wissensaustausch und die kooperative Konstruktion neuen Wissens in verschiedensten und unterschiedlich großen Gruppen ermöglichen. Beispiele dieser möglichen Anwendungen sind kooperativ erstellte Texte (Wikis), Tools zum Austausch von Ressourcen (File-Sharing, Social Bookmarking & Collaborative Tagging) und soziale Netzwerke (Facebook, MySpace). Dieser hoch aktuelle, noch wenig systematisch erforschte Bereich hat einerseits hohe praktische Relevanz und bietet andererseits die Möglichkeit zur Integration von unterschiedlichen Forschungsrichtungen und - methoden.

Der Promotionsprozess zeichnet sich u.a. aus durch:

- Eine individuelle Betreuung der Doktoranden durch zwei kooperierende Dozenten
- Ein vertiefendes Seminarprogramm und die Veranstaltung von Summer Schools
- Ein begleitendes Doktorandenkolloquium zum Austausch der neuesten Forschungsergebnisse
- Die Einbindung in die bestehende Scientific Community, u.a. durch Vorträge auf internationalen Konferenzen und durch Gastaufenthalte in ausländischen Forschungseinrichtungen

Zielsetzung der Graduate School ist die Erstellung hochwertiger Dissertationen im Schnittpunkt zwischen Grundlagenforschung und Anwendungsorientierung.

### Kooperationspartner

- Die Graduate School ist ein Kooperationsprojekt der Arbeitsgruppen "Design und Implemenation integrativer Lernumgebungen", "Netzbasierter Wissensaustausch" und "Cybermedia" des IWM und dem psychologischen Institut der Universität Tübingen, vertreten durch Herrn Prof. Dr. Diehl und Herrn Prof. Dr. Heller.

Weitere Informationen zu einem Promotionsstipendium.

## Leibniz Graduate School for Knowledge Media Research

Allgemeines zur Vergabe von Promotionsstipendien
Die Stipendienvergabe erfolgt auf der Basis der von der Stiftung Medien in der Bildung, Trägerin des Instituts für Wissensmedien (IWM), erlassenen Stipendienrichtlinien. Diese Richtlinien begründen weder dem Grunde noch der Höhe nach einen Anspruch auf Vergabe eines Stipendiums. Diese Richtlinien sind, ebenso wie die „Regeln zur Sicherung guter wissenschaftlicher Praxis am IWM und Verfahren zum Umgang mit wissenschaftlichem Fehlverhalten“, zum Gegenstand der Bewilligung zu machen und müssen von der Stipendiatin / dem Stipendiaten bei der ersten Bewilligung anerkannt werden.

Das Stipendium dient der Deckung des für die Bestreitung des Lebensunterhalts der Stipendiatin / des Stipendiaten erforderlichen Bedarfs. Es verpflichtet die Stipendiatin / den Stipendiaten zu keiner Arbeitnehmertätigkeit für die Stiftung Medien in der Bildung und begründet kein rechtliches Austauschverhältnis im Sinne eines Gegenleistungsverhältnisses. Es ist gemäß § 3 Nr. 44 des Einkommensteuergesetzes einkommensteuerfrei und auch sozialversicherungsfrei.

Voraussetzungen für die Bewerbung um ein Stipendium

- Hervorragend und zügig abgeschlossenes einschlägiges Universitäts- bzw. Fachhochschulstudium mit Bachelor-, Master-, Diplom- oder vergleichbarem Studienabschluss, insbesondere der Fachrichtungen Psychologie, Erziehungswissenschaft, Soziologie, Kommunikationswissenschaften und Informatik.
- Im Regelfall einschlägige, für den Forschungsgegenstand des Instituts für Wissensmedien (IWM) relevante Schwerpunktbildung während des Studiums, die durch entsprechende Nachweise belegt sein sollte.
- Bewerbung für ein Stipendium mit
  - Bewerbungsanschreiben, aus dem die Gründe und die Motivation, sich um ein Stipendium zu bewerben, hervorgehen,
  - tabellarischer Lebenslauf, Kopie des Abitur- und Examenszeugnisses, Referenzen (falls vorhanden),
  - Kopie der Abschlussarbeit des Studiums,
  - kurzer Skizze des beabsichtigten Promotionsvorhabens mit Zeitplan sowie Einschätzung zur Relevanz des Vorhabens im Lichte des derzeitigen Forschungsstandes (max. 3 Seiten).

Voraussetzung für die Stipendienvergabe
Voraussetzung für die Vergabe eines Stipendiums ist eine vollständige und - im Falle von Bewerbungsfristen - fristgerechte Bewerbung. Über die Vergabe von Stipendien entscheidet der Direktor des IWM bzw. bei Verhinderung dessen Stellvertreter nach Anhörung des Vergabeausschusses. Ein Anspruch auf die Vergabe eines Stipendiums besteht nicht.

Dauer der Bewilligung
Die Bewilligung erfolgt grundsätzlich für einen Förderzeitraum von drei Jahren. Die Bewilligung für das zweite und dritte Jahr steht unter dem Vorbehalt einer positiven Begutachtung zum Ablauf des ersten Jahres.

Höhe des Stipendiums
Über die Höhe des Stipendiums entscheidet der Direktor nach Anhörung des Vergabeausschusses unter Berücksichtigung der Besonderheiten des jeweils konkreten Einzelfalles. Es darf den zur Deckung des für die Bestreitung des Lebensunterhalts und der Deckung des Ausbildungsbedarfs der Stipendiatin / des Stipendiaten erforderlichen Bedarf nicht überschreiten. Es beträgt in der Regel EURO 1.300.- / monatlich.

Annahme des Stipendiums
Mit der Annahme des Stipendiums verpflichtet sich die Stipendiatin / der Stipendiat, sich voll dem Stipendienzweck zu widmen. Andere Tätigkeiten bedürfen der vorherigen Zustimmung des Stipendiengebers. Es wird erwartet, dass die Forschungsarbeiten in Absprache mit dem IWM und in der Regel am IWM durchgeführt werden.